#
# spec file for package geany-plugins
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# FIXME: Files listed inside the conditional "%%if %%{gtk3_ready}" are enabled because they do build when compiled against gtk3.
# On next update, try enabling each of the disabled libs (in the %%else section) and check if they build with gtk3 or not. When all of them compile against gtk3, remove the macro and conditional.
%define gtk3_ready 1
Name:           geany-plugins
Version:        2.0
Release:        5.0.2.1.sr20250402
# FIXME: gendoc requires ctpl (http://ctpl.tuxfamily.org/)
Summary:        A collection of different plugins for Geany
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          Development/Tools/IDE
URL:            https://plugins.geany.org/geany-plugins/
Source:         http://plugins.geany.org/geany-plugins/%{name}-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM db2698cc869274aef353ba7af23d70921d944166.patch -- projectorganizer: fix invalid string comparison
Patch1:         https://github.com/geany/geany-plugins/commit/db2698cc869274aef353ba7af23d70921d944166.patch
# PATCH-FIX-UPSTREAM 644550babb52013d2625a3f8e789bbe94a335b6f.patch -- projectorganizer: Use g_pattern_spec_match_string() instead  of g_pattern_match_string()
Patch2:         https://github.com/geany/geany-plugins/commit/644550babb52013d2625a3f8e789bbe94a335b6f.patch
# PATCH-FIX-UPSTREAM geany-plugins-2.0-gcc15.patch -- Fix build with gcc 15
Patch3:         geany-plugins-2.0-gcc15.patch

BuildRequires:  devhelp-devel
BuildRequires:  fdupes
BuildRequires:  gettext-devel
BuildRequires:  intltool
BuildRequires:  libgeany0 >= 2.0
BuildRequires:  libgpgme-devel
BuildRequires:  libtool
BuildRequires:  lua51-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
# We cannot use pygtk anymore, as it is Python 2-based.
# Unless geany-plugins switches to PyGObject, we cannot have Gnome
# plugins here.
# BuildRequires:  python-gtk-devel
BuildRequires:  vala
BuildRequires:  pkgconfig(enchant) >= 1.3
BuildRequires:  pkgconfig(geany) >= 1.26
BuildRequires:  pkgconfig(glib-2.0) >= 2.16
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24
BuildRequires:  pkgconfig(gtkspell3-3.0)
BuildRequires:  pkgconfig(libgit2) >= 0.21
BuildRequires:  pkgconfig(libsoup-2.4) >= 2.4.0
BuildRequires:  pkgconfig(libxml-2.0) >= 2.6.27
BuildRequires:  pkgconfig(webkit2gtk-4.0)
# Disable this as we do not want to use this unsupported version of webkit.
# Leaving it in place to remind us to enable for newer versions if upstream ports it.
# See https://github.com/geany/geany-plugins/issues/655
#BuildRequires:  pkgconfig(webkit-1.0) >= 1.1.18
Requires:       geany >= 2.0
Requires:       lua
Enhances:       geany

%description
Geany-Plugins is a collection of different plugins for Geany,
a lightweight IDE.

%lang_package

%prep
%autosetup -p1

%build
%configure \
	--docdir=%{_docdir}/%{name} \
	%{nil}
%make_build

%install
%make_install
install -d -m755 %{buildroot}%{python_sitearch}

find %{buildroot} -type f -name "*.la" -delete -print
find %{buildroot} -size 0 -delete
%fdupes %{buildroot}%{_docdir}/%{name}
%find_lang %{name}

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc NEWS README
%{_libdir}/libgeanypluginutils.so
%{_libdir}/libgeanypluginutils.so.*
# Explicitly list plugins, so we don't lose any by accident
%dir %{_libdir}/geany-plugins
%dir %{_libdir}/geany-plugins/geanylua
%{_docdir}/%{name}/
%{_datadir}/geany-plugins/

%if %{gtk3_ready}
# List of gtk3 compatible plugins
%{_libdir}/geany/addons.so
%{_libdir}/geany/autoclose.so
%{_libdir}/geany/automark.so
%{_libdir}/geany/codenav.so
%{_libdir}/geany/commander.so
%{_libdir}/geany/defineformat.so
%{_libdir}/geany/geanyctags.so
%{_libdir}/geany/geanyextrasel.so
%{_libdir}/geany/geanyinsertnum.so
%{_libdir}/geany/lipsum.so
%{_libdir}/geany/geanylua.so
%{_libdir}/geany-plugins/geanylua/libgeanylua.so
%{_libdir}/geany/geanyminiscript.so
%{_libdir}/geany/geanypg.so
%{_libdir}/geany/sendmail.so
%{_libdir}/geany/geanyvc.so
%{_libdir}/geany/geniuspaste.so
%{_libdir}/geany/git-changebar.so
%{_libdir}/geany/lineoperations.so
%{_libdir}/geany/markdown.so
%{_libdir}/geany/overview.so
%{_libdir}/geany/pairtaghighlighter.so
%{_libdir}/geany/pohelper.so
%{_libdir}/geany/pretty-printer.so
%{_libdir}/geany/projectorganizer.so
%{_libdir}/geany/shiftcolumn.so
%{_libdir}/geany/spellcheck.so
%{_libdir}/geany/tableconvert.so
%{_libdir}/geany/treebrowser.so
%{_libdir}/geany/updatechecker.so
%{_libdir}/geany/xmlsnippets.so
%{_libdir}/geany/latex.so
%{_libdir}/geany/geanymacro.so
%{_libdir}/geany/geanynumberedbookmarks.so
%{_libdir}/geany/geanyprj.so
%{_libdir}/geany/geanydoc.so
%{_libdir}/geany/keyrecord.so
%{_libdir}/geany/vimode.so
%{_libdir}/geany/workbench.so
%{_libdir}/geany/webhelper.so
%else
# These plugins are not compatible with gtk3
%{_libdir}/geany/debugger.so
%{_libdir}/geany/markdown.so
%{_libdir}/geany/scope.so
%endif

%files lang -f %{name}.lang

%changelog
* Wed Mar 26 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Add geany-plugins-2.0-gcc15.patch: Fix build with gcc 15, patch
  lifted from gentoo.
* Thu Feb 27 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Drop libwnck2-devel BuildRequires: nothing needs this. Stops us
  from pulling in GTK2 into the build.
* Mon Aug 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire gettext-devel instead of gettext: allow OBS to
  shortcut through gettext-runtime-mini.
* Wed Jul 10 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Add upstream patches:
  + db2698cc869274aef353ba7af23d70921d944166.patch:
    projectorganizer: fix invalid string comparison
  + 644550babb52013d2625a3f8e789bbe94a335b6f.patch:
    projectorganizer: Use g_pattern_spec_match_string() instead
    of g_pattern_match_string()
* Fri Oct 20 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.0:
  * Remove unusable and unmaintained plugins: DevHelp, GeanyPy,
    Multiterm.
  * Bookmarks: Prevent duplicating bookmarks when editing line.
  * Delay updating of tasks list until document has been colorised.
  * Various fixes.
- Dropped 1178.patch since it has been upstreamed.
* Tue Sep 13 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Replace 1165.patch with 1178.patch: Solve the problem in a
  different way.
* Mon Sep  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add explicit pkgconfig(libsoup-2.4) BuildRequires: needed for
  geniuspaste.
- Add explicit pkgconfig(webkit2gtk-4.0) BuildRequires: needed for
  the markdown plugin.
* Tue Feb 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 1165.patch: GitChangeBar: Support libgit2 1.4.x
* Sun Oct 10 2021 Michael Ströder <michael@stroeder.com>
- Update to version 1.38
  * GeanyCTags
  - Fix (re-)generating ctags file with relative paths (PR #708)
  * GeanyVC
  - Report a completion status of the commit command (Issue #837, PR #1026)
  - Correct tooltip display for the attach to menubar action (Issue #1032 PR #1033)
  * PrettyPrinter
  - Use stdbool.h istead of redefining bool (Issue #1059, Issue #1023, PR #1053)
  * Spellcheck
  - Add documentation about maintaining personal dictionaries (PR #1108)
  * Treebrowser
  - Avoid double node clear (PR #1015)
  * Vimmode
  - Ignore key-presses containing command on macOS (Issue #991, PR #1099)
  - Ignore special command handling in insert mode (Issue #1075, PR #1100)
  - Enable '.' to also repeat last inserted text (Issue #1101, PR #1102)
  - Fix line operation problems when NL is missing at EOF (Issue #1060, PR #1103)
  - Add special handling to include destination char for some commands (Issue #1052, PR #1104)
  - Add some more ex commands (PR #1104)
  * Windows
  - Switch Windows builds to GTK3 and x86_64 (PR #1107).
  - Fix crashes in Git Changebar, Lua, Macro and Numbered Bookmarks plugins (PR #1106)
  - Remove Markdown and WebHelper plugins from Windows installer due to
    missing dependencies (WebkitGTK) (PR #1107)
  * Internationalization
  - Updated translations: es, pt, tr, uk
* Tue Oct 27 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to version 1.37:
  * Addons: Improve sizes of color calltip
  * Autoclose: Remove all pairing quotes
  * GeanyVC: Add support for Fossil SCM
  * GeanyVC: Allow to toggle single files with Space and Return
    keys in commit dialog
  * GitChangebar: Add compatibility with libgit2 0.99
  * LaTeX: Indent line in new environment
  * PairTagHighligher: Allow to select a matching tag
  * ProjectOrganizer: Make showing empty directories in the
    sidebar configurable
  * ProjectOrganizer: Add a keybinding for focusing the sidebar
  * ProjectOrganizer: Re-read base path when updating project
  * Vimmode: Don't use word navigation from Scintilla
  * Vimmode: Make o/O respect auto indentation
- Remove deprecated geany-plugins-Make-libgit2-compatible.patch
* Thu Apr 16 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add geany-plugins-Make-libgit2-compatible.patch: Make libgit2
  version preprocessor conditionals compatible with libgit2-0.99.
- Drop long disabled downstream patch, geany-plugins-lua-5_2.patch:
  We will move to lua 5.2 when upstream does.
* Fri Feb 21 2020 Matej Cepl <mcepl@suse.com>
- Switch off building with PyGtk (as it is Python 2-based).
* Tue Feb  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Drop geany-plugins-lang Requires: It should have been a
  Recommends, and those are not needed anymore as Supplements: are
  in place to take care of it.
* Sat Sep 28 2019 Michael Ströder <michael@stroeder.com>
- Update to version 1.36:
  + Addons: Add additional color format used at Arduino.
  + Improve support for GTK+3-support in many plugins.
  + Lineoperations:
  - Remove every n-th line.
  - Add support for locale-aware sorting.
  + Scope: Improve evaluation on-hover.
  + Updatechecker: Update URL for new geany.org-homepage.
  + VimMode:
  - Allow browsing command history using arrows.
  - Add going to beginning/end of command line.
  - Separate command and search history.
  + Workbench:
  - Save settings immediately.
  - Give sidebar a name to enable dedicated CSS styling.
  - Auto-save project on changes.
  - Add new feature "Search projects".
  - Add option to let Git decide which files to display.
- Changes from version 1.35:
  + General:
  - Windows: Install dependency translations only if selected.
  - Build: Don't rely on a pkg-config output formatting detail.
  + Addons: Update to use new plugin API.
  + Autoclose: Update to use new plugin API.
  + Automark: Update to use new plugin API.
  + Codenav: Update to use new plugin API.
  + Debugger:
  - Update to use new plugin API.
  - Fix a compiler warning.
  + Defineformat: Update to use new plugin API.
  + DevHelp: Update to use new plugin API.
  + GeanyCTags: Update to use new plugin API.
  + GeanyExtraSel: Undo workaround for rectange selection cancel
    bug (Fixed with 1.34+ Geany core release).
  + GeanyLua:
  - Fix build warnings.
  - Update to match latest Geany's Scintilla API.
  + GeanyNumberedBookmarks: Fix crash on re-unload.
  + GeanyVC: Add a commit message history.
  + GitChangebar: Fix compatibility with libgit2 0.28 API.
  + Project Organizer: Add file operations to Project Organizer.
  + Scope:
  - Correct height of "Environment" GtkTextView.
  - Show error message if no executable is set.
  - Fix "Modify" menu item being active without selection.
  + Spellcheck: Improve documentation where to put translation
    dictionaries.
  + Treebrowser: Use xdg-open for external open command.
  + Vimmode: Fix repeated commands like 10dd not working.
  + Webhelper: Update README.
  + Updated translations.
- Removed obsolete geany-plugins-fix-compat-libgit2_0.28.patch.
* Wed Feb 13 2019 bjorn.lie@gmail.com
- Add geany-plugins-fix-compat-libgit2_0.28.patch: Fix build with
  new libgit2 0.28 api.
* Sun Dec 16 2018 Michael Ströder <michael@stroeder.com>
- Update to version 1.34:
  + General:
  - New plugin: vimode: A Vim Mode for Geany (PR #735)
  - Improve Travis testsuite to run also "make distcheck"
  + Geanyctags:
  - Use base path as relative to the project file path (#698, PR #755)
  - Add apostrophes around generated tags file (PR #739)
  + GeanyLua:
  - Update Scintilla symbols for Geany 1.34 (PR #776)
  - Update glspi_keycmd.h from geany-master (PR #759)
  + Markdown:
  - Port plugin to Webkit2GTK (PR #746)
  + PoHelper:
  - Consider dash a separator when rewrapping messages (PR #696)
  - Do not leave spaces at the start of a line when rewrapping (PR #696)
  - Make sure to only replace header fields in the actual header (PR #696)
  - Update X-Generator header if present (PR #696)
  - Use Geany-Plugins version for the plugin (PR #696)
  - Fix: for locating line breaks (PR #696)
  - Fix: Properly break all multiline strings on multiple lines (PR #696)
  - Fix: regular expression replacement when no matches are found
  + Scope:
  - Add GTK3 support (#PR #750)
  + Updatechecker:
  - On Windows, the common ca-certificates bundle is included in
  - the installer for proper SSL certificate verification (PR #768)
  + Workbench:
  - Add option "Expand on hover" (PR #727)
  - Import base path on "Add project..."
  - Allow to remove files or directories
  - Support live update (PR #695, #659)
  + Internationalization:
  - Updated translations: de, es, pt
* Mon Mar  5 2018 badshah400@gmail.com
- Update to version 1.33:
  + General:
  - Rename plugin geanylatex to latex
  - utils lib: added new function
    'gp_filelist_scan_directory_full()
    (gh#geany/geany-plugins#681)
  + Addons: Show color tip and start Color Chooser with double
    click (gh#geany/geany-plugins#664)
  + GeanyLua:
  - Add filetype to set in geany.newfile()
    (gh#geany/geany-plugins#652)
  - Add function geany.reloadconf() (gh#geany/geany-plugins#653)
  - Fix right-trim.lua (gh#geany/geany-plugins#670)
  - Update glspi_keycmd.h to match latest Geany version
    (gh#geany/geany-plugins#662)
  - Update to match latest Geany's Scintilla API
    (gh#geany/geany-plugins#685)
  + PrettyPrinter: Allow to pretty print a selection only
    (gh#geany/geany-plugins#683)
  + Spellcheck:
  - Remember 'Check while typing' setting between sessions
    (gh#geany/geany-plugins#667, gh#geany/geany-plugins#680)
  - Support Enchant 2.0 and later (gh#geany/geany-plugins#674)
  + Treebrowser: Fallback to "text-x-generic" icon if info lookup
    fails (gh#geany/geany-plugins#682)
  + VC: Remember the commit dialog size
    (gh#geany/geany-plugins#679)
  + Workbench:
  - Add "Create file here..."/"Create directory here..."
    (gh#geany/geany-plugins#681)
  - Renamed "folder" to "sub-directory"
    (gh#geany/geany-plugins#678)
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner.
* Tue Dec 19 2017 luc14n0@linuxmail.org
- Update to version 1.32:
  + General:
  - New plugin: Workbench (gh#geany/geany-plugins#460).
  - Add a common utils library (gh#geany/geany-plugins#622).
  + Addons - Mark Word: Deselect when the selection changes
    (gh#geany/geany-plugins#614).
  + GeniusPaste - Enable HTTPS for pastebin.geany.org
    (gh#geany/geany-plugins#635).
  + GitChangebar - Add the possibility to undo hunk at cursor
    position (gh#geany/geany-plugins#531).
  + PrettyPrinter - Add saving and loading of preferences in/from a
    file (gh#geany/geany-plugins#494, gh#geany/geany-plugins#581).
  + ProjectOrganizer:
  - Close dir created with g_dir_open() in some special cases as
    well as don't keep directories open when enumerating their
    children (gh#geany/geany-plugins#605).
  - Use stock icons instead of the ones provided by the plugin
    (gh#geany/geany-plugins#625).
  + Scope:
  - Only allow selection of folders for "working dir"
    (gh#geany/geany-plugins#623).
  - Add tooltips to toolbar buttons (gh#geany/geany-plugins#617).
  + XmlSnippets - Activate unit tests for the plugin.
  + Updated translations.
- Adopt the use of %%make_build macro rather than raw make command,
  following the best practices.
- Pass --docdir=%%{_docdir}/%%{name} to configure, fixing the
  documentation location.
- Reflecting the above change, point fdupes to this new location.
- Add ldconfig post/postun scriptlets now that the package shipps a
  shared library.
* Sat Sep 16 2017 luc14n0@linuxmail.org
- Update to version 1.31:
  + General:
  - New plugin: keyrecord (gh#geany/geany-plugins#460).
  - Add a note to plugins which are currently orphaned and might
    not receive further fixes (gh#geany/geany-plugins#540).
    Affected plugins:
    . Geanydoc.
    . GeanyExtrasel.
    . GeanyInsertNum.
    . GeanyLua.
    . GeanyPG.
    . GeanyPrj.
    . GeanyVC.
    . PrettyPrinter.
    . Scope.
    . Shiftcolumn.
    . Treebrowser.
  + Addons: Enable Mark Word also for newly opened documents
    (gh#geany/geany-plugins#563).
  + Automark: Extend documentation (gh#geany/geany-plugins#582).
  + GeanyDoc: Make OK the default button in interactive mode
    (gh#geany/geany-plugins#566).
  + GeanyExtrasel: Fix issues related to Scintilla Rectancle select
    (gh#geany/geany-plugins#568).
  + GeanyLua, GeanyMacro, GeanyNumbersBookmarks: Pass a GdkKeymap
    to gdk_keymap_* functions to prevent crashes on Windows and
    critical warnings on other platforms
    (gh#geany/geany-plugins#586).
  + GeniusPaste: Update configuration for shipped pastebins
    (gh#geany/geany-plugins#551).
  + GitChangebar: Fix spurious line wrapping
    (gh#geany/geany-plugins#564).
  + LineOperations: Add a feature to keep unique lines
    (gh#geany/geany-plugins#560).
  + PrettyPrinter: Add missing README, COPYING, NEWS and AUTHORS
    files (gh#geany/geany-plugins#580).
  + ProjectOrganizer: Fix a crash by ensuring project is open
    before trying to expand the tree (gh#geany/geany-plugins#555,
    gh#geany/geany-plugins#557, gh#geany/geany-plugins#559).
  + Scope: Correct a misleading error message
    (gh#geany/geany-plugins#561).
  + Spellcheck:
  - Stop processing if the document gets invalid to prevent
    crashes while file gets closed during long check runs
    (gh#geany/geany-plugins#547).
  - Add style mappings for Rust and PHPSCRIPT.
  + Updatechecker: Remove deprecated soup call
    (gh#geany/geany-plugins#541).
  + Updated translations.
* Tue Jul 11 2017 badshah400@gmail.com
- Rename misleadingly named macro %%%%{gtk3_enable} to
  %%%%{gtk3_ready} and set it to true (1). Used to distinguish
  between gtk-ready plugins and those that are not yet so in the
  file-list.
* Wed Mar  8 2017 badshah400@gmail.com
- Update to version 1.30:
  + Automark:
  - Fix a possible crash if nothing is selected for automarking.
  - Replace internal usage of deprecated functions.
  + Commander:
  - Fix a possible crash on startup with latest GTK3.
  + Debugger: Fix a possible crash if debug-modus is enabled
    (gh#geany/geany-plugins#511).
  + Geanyctags:Show online help via help button
    (gh#geany/geany-plugins#521).
  + GeanyDoc:
  - Improve compatibility with Gtk3.
  - Allow to use current word as initial text in interactive
    mode (gh#geany/geany-plugins#457).
  + GeanyLua:
  - Remove deprecated GeanyFunctions from interface provided by
    this plugin (gh#geany/geany-plugins#439).
  - Fix build with latest Scintilla
    (gh#geany/geany-plugins#510).
  + GeanyPy: Sync with upstream GeanyPy version
    (gh#geany/geany-plugins#527).
  + Lineoperations: Add support for selections
    (gh#geany/geany-plugins#378).
  + Lipsum: Add a space before restarting Lorem Ipsum text
    (gh#geany/geany-plugins#513).
  + Markdown:
  - Allow exporting Markdown as HTML
    (gh#geany/geany-plugins#502).
  - Fix relative paths (gh#geany/geany-plugins#501).
  + PairTagHighlighter:
  - Add keybinding for jumping to matching tag
    (gh#geany/geany-plugins#466).
  - Improve compatibility with Gtk3
    (gh#geany/geany-plugins#466).
  + ProjectOrganizer:
  - Show online help via help button
    (gh#geany/geany-plugins#521).
  - Remember expanded directories in the sidebar when reloading
    (gh#geany/geany-plugins#528).
  + Spellcheck: Treat underscore as word separator
    (gh#geany/geany-plugins#512).
  + Tableconvert: Fix markup of documentation.
  + Treebrowser:
  - Fix a possible memory leak (gh#geany/geany-plugins#478).
  - Add a keybinding to follow current file
    (gh#geany/geany-plugins#524).
  - Allow to show menu also with Shift+F10
    (gh#geany/geany-plugins#523).
  - Fix a bug addding files to file list again and again when
    using refresh-function and no file is selected.
    (gh#geany/geany-plugins#525)
  - Don't change directory on project save
    (gh#geany/geany-plugins#536).
  + Updated translations.
- Bump the version of libgeany0 in BuildRequires to 1.29
  (following configure.ac changes).
- geanydoc now builds with gtk3, so restore it to the allowed
  file-list.
* Thu Jan 26 2017 firebird209@gmail.com
- Update to version 1.29 (boo#1022222):
  + General:
  - Rename plugin GeanyLipsum to Lipsum
    (gh#geany/geany-plugins#472).
  + Addons:
  - Add a function to deselect marked words with one click
    (gh#geany/geany-plugins#481).
  + Commander:
  - Add keybindings for triggering a particular filter type
    (gh#geany/geany-plugins#468).
  + GeanyGenDoc:
  - Fix typos in README (gh#geany/geany-plugins#476).
  + Git-Changebar:
  - Fix an issue access the git repository in combination with
    libgit2 0.24.2.
  - Fix an off-by-one issue in tooltip hunk width calculation
    cropping 1px on the right.
  - Fix handling of documents starting with a BOM
    (gh#geany/geany-plugins#483, gh#geany/geany-plugins#482).
  + Spellcheck:
  - Strip single quotes from words' beginning and end
    (gh#geany/geany-plugins#484).
  - Fix a memory leak on duplicate dictionaries
    (gh#geany/geany-plugins#480).
  + Treebrowser:
  - Fix a typo in configuration parsing causing option for
    "open new files" have not being save/restored correctly
    (gh#geany/geany-plugins/#469, gh#geany/geany-plugins#473).
  + Updated translations.
* Mon Sep 19 2016 dimstar@opensuse.org
- Drop pkgconfig(vte) BuildRequires: geany-plugins still uses vte2
  which is not compatible with the GTK3 build of geany. This change
  does not result in any difference, since the package switched to
  GTK3 a while ago and the GTK2/VTE2 based plugins have not been
  shipped since then anyway.
* Wed Jul 20 2016 badshah400@gmail.com
- Update to version 1.28:
  + General:
  - Rename plugin GeanySendMail to SendMail
    (gh#geany/geany-plugins#43).
  - Fix some inconsistency in plugins' READMEs
    (gh#geany/geany-plugins#453).
  + Windows build: Update dependencies shipped with the package.
  + Addons:
  - tasks: Strip comment-closing sequence from task text
    (gh#geany/geany-plugins#416).
  - tasks: Do not extract tokens from non-comments
    (gh#geany/geany-plugins#416).
  + Debugger: Fix escaping target executable path if it contains
    non-ASCII (gh#geany/geany-plugins#416,
    gh#geany/geany-plugins#451).
  + GeanyGenDoc: Fix build with old rst2html
    (gh#geany/geany-plugins#414).
  + GeanyLaTeX:
  - Fix a conditional end of undo action. Without an undo-action
    might run forever (gh#geany/geany-plugins#416).
  - Improve support for GTK3 (gh#geany/geany-plugins#410).
  + GeanyLipsum: Add ellipsis to menu item requiring further user
    input (gh#geany/geany-plugins#452).
  + GeanyMacro: Fix GTK3 support (gh#geany/geany-plugins#410).
  + GeanyNumberedBookmarks: Fix GTK3 support
    (gh#geany/geany-plugins#410).
  + GeanyPrj: Fix GTK3 support (gh#geany/geany-plugins#410).
  + GeanyPy: Fix build with current Geany
    (gh#geany/geany-plugins#363).
  + PairTagHighlighter: Fix a crash when the tag name is missing
    (gh#geany/geany-plugins#442, gh#geany/geany-plugins#446,
    gh#geany/geany-plugins#447).
  + Prettyprinter: Fix several memory leaks
    (gh#geany/geany-plugins#364).
  + ProjectOrganizer: Fix duplicated tab in Project Properties.
  + Scope: Fix dependency checks on Windows
    (gh#geany/geany-plugins#409).
  + Shiftcolumn: Fix handling of end-to-start selections
    (gh#geany/geany-plugins#366).
- Changes from version 1.27: See
  /usr/share/doc/packages/geany-plugins/NEWS or online at
  https://github.com/geany/geany-plugins/blob/1.27.0/NEWS.
- Update file list:
  + geanylatex, geanymacro, geanynumberedbookmarks, geanyprj
    are GTK3 compatible now.
  + New plugin: lineoperations.
* Tue Feb 16 2016 zaitor@opensuse.org
- Disable pkgconfig(webkit-1.0), as we do not want to use this as
  it is unsupported by upstream.
* Tue Jan 12 2016 badshah400@gmail.com
- Geany was switched to build against gtk3, so also switch
  this -plugins package to gtk3 too:
  + Disable the following plugins because they do not build
    against gtk3: Debugger, DevHelp, GeanyDoc, GeanyGenDoc,
    GeanyLaTeX, GeanyMacro, GeanyNumberedBookmarks, GeanyPrj,
    Geanypy, Markdown, MultiTerm, Scope, WebHelper.
  + Update BuildRequires:
  - Update geany version to 1.26.
  - Replace pkgconfig(gtk+-2.0) by pkgconfig(gtk+-3.0).
  - Replace pkgconfig(gtkspell-2.0) by pkgconfig(gtkspell3-3.0).
  - Remove gconf2-devel, no longer required after the switch to
    gtk3.
* Thu Dec 31 2015 badshah400@gmail.com
- Update to version 1.26:
  + General: Add a note about deprecating Waf build system --
    will be removed with 1.27.
  + Addons:
  - Add new feature to copy path of current file into clipboard
    (#291).
  - Update bookmark list also on any line changes in the
    document (SF#129, SF#39, #284).
  - Add GTK3 support (#271).
  + GeanyPy: Fix Python library loading on Debian based systems.
  + GeanyVC:
  - Add GTK3 support (#300).
  - Little improvements on commit dialog (#300).
  + GitChangeBar: Add support for libgit2 0.23 (#283).
  + Multiterm: Make a lot of strings translatable (#254).
  + Pohelper: Fix untranslated and fuzzy count in the stats
    dialog (#292).
  + ProjectOrganizer: Fix some features when the sidebar was
    never visible.
  + Scope: Use Geany spawn: maximum GDB line length fixed to
    1MB, no CPU time wasted when IDLE under Windows, 3
    preferences deleted.
  + Spellcheck: Add an option to show spelling suggestion on top
    of the context menu instead of in a submenu (still default)
    (#287, #290).
  + Updated translations.
- Update requied libgeany version in BuildRequires.
- Remove conditional from pkgconfig(libgit2) BuildRequires: Now
  builds with the version in factory.
* Sun Jul 26 2015 trcs@gmx.com
- Update to version 1.25:
  + removed geany-plugins-GCond-usage.patch, fixed upstream
  + removed geany-plugins-gdb-7_7.patch, fixed upstream
  + disabled geany-plugins-lua-5_2.patch: it breaks GeanyLua build
  + General:
  - GProject is renamed to ProjectOrganizer
  - New plugin Automark
  - New plugin GeanyCtags
  - New plugin GitChangeBar
  - New plugin Overview
  + Addons:
  - Improve URI selection
  + Autoclose:
  - Add Whitesmith style bracket formatting support
  + CodeNav:
  - Implement Go to File feature
  + Commander:
  - Improve sorting algorithm
  + Debugger:
  - Fix crash with GDB 7.7
  + GeanyLaTeX:
  - Fix automatic capitalization of multi-byte characters
  + GeanyVC:
  - Add support for WinMerge external diff viewer
  + ProjectOrganizer:
  - Add an "external directory" feature
  - Add find tag by name
  - Add ignored file patterns
  - Performance improvements in tag generation using updated Geany
    API
  + MultiTerm:
  - Fix build with recent Vala versions
  + PairTagHighlighter:
  - Fix clearing previous indicators (PR #200)
  + PoHelper:
  - Add a statistics dialog
  - Fix handling of plural forms
  + Scope:
  - Fix building on GNU/Hurd (PR #146)
  + Spellcheck:
  - Don't check code of scripting languages embedded in HTML
  - Add option to perform a spell check on document open (closes
    SF #137)
  + Tableconvert:
  - Improve handling of non-LF line ends
  - Add support for DokuWiki syntax
  + WebHelper:
  - Add support for basic bookmarks
  + Internationalization:
  - Update translations: de, fr, pt, ru
* Wed Nov 19 2014 nick.schrader@mailbox.org
- Debugger
  + Add geany-plugins-GCond-usage.patch: Fixed bug SF#116
    that made the whole application crash because of GLib (bnc#906659).
  + Add geany-plugins-gdb-7_7.patch: Fixed bug SF#112 that
    made the whole application crash because of GDB (bnc#906659).
* Mon Apr 21 2014 trcs@gmx.com
- Update to version 1.24:
  + New plugin Pohelper.
  + New plugin PairTagHighlighter.
  + New plugin Autoclose.
  + New plugin Geanypy (Python bindings).
  + New plugin Defineformat.
  + Build system improvements.
  +Commander: Add Gtk3 support.
  + Debugger: Fixing a crash when re-loading plugin.
  + GeanyGenDoc:
  - Add Gtk3 support.
  - Fix a memory leak.
  + GeanyExtraSel: Add "Toggle Rectangular/Stream".
  + GeanyInsertNum:
  - Add Gtk3 support.
  - Increase maxlines to 250000.
  + GeanyLipsum:
    + Add Gtk3 support.
  - Ensure whitespace between repetitions of Lorem Ipsum text.
  + GeanyLua:
  - Add Gtk3 support.
  - Re-enable build with C89.
  + GeanyMiniScript: Add Gtk3 support.
  + GeanyPG: Improve portability and check for system requirements.
  + GeanyVC:
  - Add support for Subversion 1.7.
  - Limit the display of diff output to 16 KB to not freeze the
    UI on huge commit-diffs.
  - Show line and column of the cursor in the commit message text
    window.
  + GProject:
  - Add Gtk3 support.
  - Display content-type-specific icons for files in the sidebar.
  - Make toolbar buttons insensitive when no files displayed.
  - Smaller fixes and improvements.
  + Markdown:
  - Add Gtk3 support.
  - Fix scroll jumping behavior.
  + Multiterm: Implement the other config VTE properties.
  + Prettyprinter: Add Gtk3 support.
  + Scope:
  - Add Gtk3 support.
  - Add support for registers.
  - Various fixes and improvements.
  + Shiftcolumn: Removed default keybindings.
  + Spellcheck:
  - Add Gtk3 support.
  - Fix check for default language if LANG contains UTF-8.
  - Remove check while typing idle callback when unloading the
    plugin.
  - Improve stripping of whitespace and punctuation characters.
  - Fix crash when closing a document quickly after modifying it.
  + Tableconvert: Add support for HTML tables in markdown files.
  + TreeBrowser:
  - Add Gtk3 support.
  - Don't collapse expanded child of node when node gets
    selected.
  - Add and improve some keybindings.
  - Add a way to open newly created files.
  - Focus editor on file open.
  + Updatechecker: Fix comparing major versions.
  + WebHelper: Add Gtk3 support.
  + Updated translations.
* Sun Mar 24 2013 dimstar@opensuse.org
- Update to version 1.23:
  + Add new plugin Commander
  + Add new plugin markdown
  + Add new plugin Scope
  + Removing plugin geanyGDB
  + Improvement of error handling in autogen.sh
  + Improvement of general documentation
  + Buildfix with waf on Windows-Systems
  + Addons:
  - Fixing of memory leaks
  - Little rewordings
  + Devhelp:
  - Fix API-calls for older GTK-versions
  - Fix a signal to avoid crash on closing of Geany
  + GeanyGenDoc: Improvement of waf-build.
  + GeanyLaTeX: Fix installation path for documentation.
  + GeanyLua:
  - Update of Scintilla bindings to 3.2.0
  - Improve pointer->int casts
  - Revisiting mechanism to find Lua-package on configuration-time
  + GeanyMacro: Fix some typos.
  + GeanyPG: Fix adding of \0 when encryption a selection
    (sf#3557458)
  + GeanyPrj: Buildfix for function not marked as external.
  + GeniusPaste:
  - Fixing of memory leaks
  - Fixing of a invalid memory free
  + Spellcheck: Perform a recheck/clear when toggling 'check while
    typing' (sf#3495051)
  + Tableconvert:
  - Rework to be more generic.
  - Improvement of LaTeX-tables being created.
  + Treebrowser:
  - Added backspace to browse up a directory.
  - Eexpand/collapse with spacebar.
  + Webhelper:
  - Show the currently hovered link in the statusbar.
  - Don't use deprecated GTK API.
- No longer pass --enable-geanygdb to configure, as the geanygdb
  plugin has been dropped by upstream.
* Wed Mar 20 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Wed Aug 15 2012 dimstar@opensuse.org
- Update to version 1.22:
  + General:
  - Autotools build system improvements
  - Add new plugin GeanyMiniScript
  - Add new plugin GeniusPaste
  - Add new plugin MultiTerm
  - Disable GeanyGDB by default on build with autotools
  + Addons:
  - Add word wrapping addon
  + Debugger:
  - Fix build with --as-needed
  - Fix crash on 64 bit platform (sf#3449480)
  - Use asynchronous methods when possible not to freeze the UI
  - Display thread information in the stack window
  - Properly handle spaces in filenames
  - Various other bugfixes and improvements
  + Devhelp:
  - Bundle libdevhelp 2.32
  - Remove support for Google Code Search
  + GeanyLaTeX:
  - Fix crash with recent Geany versions
  - Ignore files autogenerated by biblatex in suggestions for
    cite
  + GeanyLua:
  - Fix build with recent GLib
  + GeanyMacro:
  - Add support for editing macros events
  - Support search next/search prev
  + GeanyNumberedBookmarks:
  - Only save file status if non-empty
  - Add support for saving file status next to the file itself
  - Save non-numbered bookmarks too
  + GeanyPG:
  - Fix build with --as-needed
  - Fix encryption to an untrusted key
  + GeanyPrj:
  - Add "find in project" keybinding
  - Add a setting to hide the sidebar
  + GeanyVC:
  - Go to the selected line upon blame
  - Add support for displaying the VC menu in the menubar
  + GProject:
  - Fix a crash when a project file is missing
  - Support Geany 1.22
  + Tableconvert:
  - Fix SQL tables generation
  + TreeBrowser:
  - Fix permissions on new files (sf#3415045)
  - Add "create new file" and "create new directory" keybindings
  + WebHelper:
  - Fix crash with recent versions of WebKitGTK
  - Save and restore inspector docking state
  + Updated translations.
- Pass --enable-geanygdb to configure to enable the gdb plugin.
* Tue Jan 10 2012 dimstar@opensuse.org
- Use versioned BuildRequires where they are specified in the build
  system.
- Add geany-plugins-lua-5_2.patch: Fix build with lua 5.2.
* Wed Nov 16 2011 dimstar@opensuse.org
- Update to version 0.21.1:
  + Add geanylatex/doc/ to autotools build system.
- Changes from version 0.21:
  + General:
  - Renew autotools build system
  - Add new plugin Debugger
  - Add new plugin Devhelp
  - Add new plugin GeanyPG
  - Add new plugin GeanyMacro
  - Add new plugin GeanyNumberedBookmarks
  - Add new plugin Tableconvert
  - Add new plugin XMLSnippets
  + Addons:
  - DocList addon: Add preference to define the order of the
    documents in the list (sf#3204573)
  - Tasks addon: Activate and update the task list when the Tasks
    addon is enabled
  + GeanyLaTeX:
  - Moved LaTeX-menu to a separate menu inside Geany main menu
  - Added a feature to autocapetlise letters on typing on begin
    of a sentence
  - Added a way to put a icon for \LaTeX{}-wizard into Geany's
    main toolbar
  - Added a dialog for inserting BibTeX references based on
    available *.bib-files
  - Upgrade plugin API to version 199
  - Ensure to not insert {} after \^ and \_
  - Adding a keystroke to toggle inserting {} after ^ and _
  - Fix an issue with wrong inserted formating using a keybinding
  - Small update to enable i18n also on Geany >= 0.21
  - Various bugfixes and memory leak fixes.
  + GeanyLipsum:
  - Small update to enable i18n also on Geany >= 0.21
  + GeanySendMail:
  - Some minor cleaning up of code
  - Fix for an isue with replacing of command string in case of
    %%r has not being used
  - Don't double free a variable which might ended up inside a
    segmentation fault when using plugin function more than once.
  - Small update to enable i18n also on Geany >= 0.21
  + GeanyVC:
  - Some smaller fixes for compiler warnings and memory leaks
  - Small update to enable i18n also on Geany >= 0.21
  + Spell Check:
  - Reduce artifacts on partially checked words
  - Improve 'Check as you type' feature, make it more reliably
  + Tableconvert:
  - Adding new plugin, helping on converting tabulator separated
    list into table supporting LaTeX, HTML and SQL so far.
  - Small update to enable i18n also on Geany >= 0.21
  + Updatechecker:
  - Fix an issue with init threads for older GTK/glib versions by
    updating to Geany API version 203.
  - Small update to enable i18n also on Geany >= 0.21
  - Fix a typo inside waf-build system
  + WebHelper:
  - Fix creation of configuration directory in some cases.
  - Fix missing update of navigation buttons on anchor links.
  - Fix thread initialization problem.
  - Fix some issues with keybingins on secondary windows.
  - Add a keybinding to show/hide web view's window (sf#3156262).
  - Allow for better configuration of secondary windows.
  + Updated translations.
- Re-enable webhelper plugin by uncommenting pkgconfig(webkit-1.0)
  BuildRequires.
- Add pkgconfig(vte) BuildRequires for the new debugger plugin.
- Add libgpgme-devel BuildRequires for the new GeanyPG plugin.
* Wed Jan 12 2011 vuntz@opensuse.org
- Update to version 0.20:
  + General:
  - Update of Waf build system.
  - Add new plugin UpdateChecker.
  - Add new plugin WebHelper.
  + GeanyExtraSel:
  - Respect 'Smart' home key (Geany does now).
  - Fixed Scintilla Shift+movement key convertion of rectangle
    selection.
  - Virtual spaces support.
  - Per-file column mode.
  - Added "Set Anchor", "Select to Anchor" and "Rectangle Select
    to Anchor".
  + GeanyGenDoc:
  - Bump dependency on CTPL to 0.3.
  - Add a popup menu for common actions in the documentation type
    selector.
  - Fix indentation of inserted documentation blocs.
  - Documentation type now defaults to Doxygen (rather than
    nothing).
  - Add policy PASS to completely ignore a symbol.
  - Add basic rules for PHP.
  - Fix build against GTK+ 2.16.
  - Don't copy the system configuration file to the user's one
    when hitting "Edit Current Language Configuration", only
    write it when saving changes.
  + GeanyInsertNum:
  - Thin selection support.
  + GeanyLaTeX:
  - Move LaTeX-menu to a separate menu inside Geany main menu.
  - Add a feature to auto-capitalize letters on typing on begin
    of a sentence.
  - Add a way to put an icon for LaTeX-wizard into Geany’s main
    toolbar.
  - Added a dialog for inserting BibTeX references based on
    available *.bib-files.
  + GeanySendMail:
  - Minor code cleanup.
  + TreeBrowser:
  - Added bookmarks support.
  - Added keybindings support.
  - Added mime type icons in the tree.
  - Many bugfixes and code improvements.
  + Updated translations.
- Move to pkgconfig()-style BuildRequires:
  + Old ones: enchant-devel, geany-devel, gtkspell-devel,
    lua-devel.
  + New ones: enchant, geany, gtkspell-2.0, lua.
- Explicitly add required pkgconfig() BuildRequires: glib-2.0,
  gtk+-2.0.
- Add missing required pkgconfig() BuildRequires: libxml-2.0.
- Remove unneeded explicit pkg-config BuildRequires: when building
  GTK+-related apps, it's guaranteed to be there.
- Remove list of plugins from description: it will get outdated
  anyway.
- Explicitly list plugins we ship to make sure we don't lose any on
  updates.
* Wed Aug 25 2010 vuntz@opensuse.org
- Remove .la files.
- Add geany Enhances.
- Remove explicit dependencies on enchant and gtkspell: they will
  be added automatically.
- Fix license tag to be "GPLv2+; GPLv3+".
* Sun Aug 15 2010 badshah400@gmail.com
- Further spec file cleanup thanks to DimStar
* Thu Aug 12 2010 badshah400@gmail.com
- spec file cleanup
* Thu Aug 12 2010 badshah400@gmail.com
- Initial package (upstream version 0.19)
